c--------------------------------------------------------------------
      subroutine glopt2(nrmax,a,z,e,fkay1,drho1,ueff,uso,bdrc0)
c
c  Global relativistic optical potential for neutron by Shen et al.
C                                                 PRC43 2773(1991)
C  MN_AV is used for nucleon mass.
c  Original by k.K (1991/10/30); Modified by M.I(2009/9/18),2016.4.22
c--------------------------------------------------------------------
c INPUT
c       a   : target mass number
C       z   : target charge
C       e   : incident kinetic energy in lab. frame (MeV)
C     fkay1 : momentum of N-A c.m. frame (1/fm)
C     drho1 : mesh size of rho(=k*dr)
C     nrmax : number of mesh points in wave func. calcul.
c LOCAL
c       vv  : real vector potential strength
c       rv  : real vec. radius parameter
c       av  : real vec. diffuseness
c       wv  : imag vec. pot. st.
c       rvi : imag vec. rad. par.
c       avi : imag vec. diff.
c       vs  : real scalar pot. st.
c       rs  : real sca. rad. par.
c       as  : real sca. diff.
c       ws  : imag sca. pot. st.
c       rsi : imag sca. rad. par.
c       asi : imag sca. diff.
C OUTPUT
c       ueff(nr) :U_cen(r)/E 
c       uso (nr) :U_so/E
c       bdrc0(nr):(E+M+Us-U0)/(E+M)
c---------------------------------------------------------------------
c Important Remark
c  In the paper of Shen et al. PRC43 2773(1991)
c  energy dependence of the potential parameters is expressed 
c  as the function of the projectile energy including mass.
c  However, judging from the demonstrated figures, 
C  it seems to be expressed as the function of the incident kinetic energy.
C  Therefore, in this program we use the incident kinetic energy in lab. 
c  for the potential parameter formulas.        
c----------------------------------------------------------------------
      complex us,uvvc,bbb,udw1,ud1,udw
      complex ueff(*),uso(*),bdrc0(*)
c
      real*8 hc/197.326968d0/
      REAL*8 MN_AV/938.91937d0/
c
      hck=hc*fkay1
ccc        edrc=sqrt(u**2+hck**2)
      edrc=sqrt(MN_AV**2+hck**2)
      alpha=1.0-2.0*z/a
      beta=abs((a-64.0)/(a+16.0))**1.278
      vv = 304.08-0.1103*e**(0.8451+0.000634*a)
     1          -0.0000922*e**(1.968-0.000787*a)-2.295*alpha-5.666*beta
      rv = 1.164
      av = 0.5746
      wv =-5.090-(0.2146+0.0000464*a)*e**(0.8945-0.000283*a)
     1          +0.00000562*beta*e**2+23.692*alpha+1.982*beta
      rvi= 1.239
      avi= 0.4378
      vs =-379.66-(0.05492+0.0000241*a)*e
     1          -3.637*alpha+13.328*beta
      rs = 1.159
      as = 0.5923
      ws =-14.21+(0.2820-0.000395*a)*e**(0.8934-0.000285*a)
     1          +18.895*alpha-1.189*beta
      rsi=1.239
      asi=0.4378
c------------------------------------------------------------------------
C CALCULATE SHROEDINGER EQUIVALENT POTENTIAL
C------------------------------------------------------------------------
      t2=fkay1*A**0.3333333
      rhos =t2*rs
      rhosi=t2*rsi
      rhov =t2*rv
      rhovi=t2*rvi
      fkayas=fkay1*as
      fkaasi=fkay1*asi
      fkayav=fkay1*av
      fkaavi=fkay1*avi
c        f1=u/edrc
      f1=MN_AV/edrc
      f2=0.5/edrc
      vsdw=vs/fkayas
      wsdw=ws/fkaasi
      vvdw=vv/fkayav
      wvdw=wv/fkaavi
c
      rho=drho1
      do 500 nr=1,nrmax+3
          rho1=1.0/rho
          xs=(rho-rhos)/fkayas
          xsi=(rho-rhosi)/fkaasi
          xv=(rho-rhov)/fkayav
          xvi=(rho-rhovi)/fkaavi
          exs =exp(xs)
          exsi=exp(xsi)
          exv =exp(xv)
          exvi=exp(xvi)
          ss1  =1.0/(1.0+exs)
          ssdw1=exs*ss1
          ssdw2=ssdw1*ss1
          ssi1  =1.0/(1.0+exsi)
          ssdwi1=exsi*ssi1
          ssdwi2=ssdwi1*ssi1
          sv1  =1.0/(1.0+exv)
          svdw1=exv*sv1
          svdw2=svdw1*sv1
          svi1  =1.0/(1.0+exvi)
          svdwi1=exvi*svi1
          svdwi2=svdwi1*svi1
          uvvc=cmplx(vv*sv1,wv*svi1)
          us  =cmplx(vs*ss1,ws*ssi1)
c          bbb=us-uvvc+edrc+u
          bbb=us-uvvc+edrc+MN_AV
          bdrc0(nr)=bbb/(edrc+MN_AV)
ccc  drw*drw*drw*drw
          addr=vsdw*ssdw2*(rho1+0.5/fkayas-ssdw1/fkayas)
     1        -vvdw*svdw2*(rho1+0.5/fkayav-svdw1/fkayav)
          addi=wsdw*ssdwi2*(rho1+0.5/fkaasi-ssdwi1/fkaasi)
     1        -wvdw*svdwi2*(rho1+0.5/fkaavi-svdwi1/fkaavi)
          udw1=cmplx(addr,addi)/bbb
          adr =-vsdw*ssdw2+vvdw*svdw2
          adi =-wsdw*ssdwi2+wvdw*svdwi2
          ud1 =cmplx(adr,adi)/bbb
          udw =udw1+(3.0/4.0)*ud1**2
          ueff(nr)= 2.*edrc/hck**2*(uvvc+f1*us+f2*(us*us-uvvc*uvvc))+udw
ccc  so*so*so*so
          uso(nr)=-2.0/rho*ud1
          rho=rho+drho1
 500   continue
      return
      end
